@@ -65,7 +65,11 @@ KTNEFProperty &KTNEFProperty::operator=(const KTNEFProperty &other)
 QString KTNEFProperty::keyString() const
 {
     if (d->_name.isValid()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         if (d->_name.type() == QVariant::String) {
+#else
+        if (d->_name.metaType().id() == QMetaType::QString) {
+#endif
             return d->_name.toString();
         } else {
             return mapiNamedTagString(d->_name.toUInt(), d->_key);
@@ -77,7 +81,11 @@ QString KTNEFProperty::keyString() const
 
 QString KTNEFProperty::formatValue(const QVariant &value, bool beautify)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (value.type() == QVariant::ByteArray) {
+#else
+    if (value.metaType().id() == QMetaType::QByteArray) {
+#endif
         // check the first bytes (up to 8) if they are
         // printable characters
         QByteArray arr = value.toByteArray();
@@ -133,5 +141,9 @@ QVariant KTNEFProperty::name() const
 
 bool KTNEFProperty::isVector() const
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     return d->_value.type() == QVariant::List;
+#else
+    return d->_value.metaType().id() == QMetaType::QVariantList;
+#endif
 }
